lilypondfiletools.PaperBlock
============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.format

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.is_formatted_when_empty

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

.. autoattribute:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.minimal_page_breaking

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__repr__

   .. note:: Inherited from :py:class:`lilypondfiletools._AttributedBlock <abjad.tools.lilypondfiletools._AttributedBlock._AttributedBlock._AttributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.PaperBlock.PaperBlock.PaperBlock.__str__

   .. note:: Inherited from `__builtin__.object`
